#!/bin/bash
debug=""
#debug="echo "

cd `dirname $0`
LANG=C
SPEC=../SPECS/vim.spec
CHANGES=1

DATE=`date +"%a %b %d %Y"`
MAJORVERSION=`grep "define baseversion" $SPEC | cut -d ' ' -f 3`
ORIGPL=`grep "define patchlevel" $SPEC | cut -d ' ' -f 3 | sed -e "s/^0*//g"`
ORIGPLFILLED=`printf "%03d" $ORIGPL`

if [ ! -d vim-upstream ]; then
   git clone https://github.com/vim/vim.git vim-upstream
else
   pushd vim-upstream
   git pull
   popd
fi

pushd vim-upstream
# get the latest tag. Might be tricky with other packages, but upstream vim uses just a single branch:
LASTTAG=$(git describe --tags $(git rev-list --tags --max-count=1))
# vim upstream tags have the form v7.4.123. Remove the 'v' and get major release and patchlevel:
echo LASTTAG=$LASTTAG
UPSTREAMMAJOR=$(echo $LASTTAG | sed -e 's/v\([0-9]*\.[0-9]*\).*/\1/')
LASTPL=`echo $LASTTAG| sed -e 's/.*\.//'`
echo LASTPL=$LASTPL
LASTPLFILLED=`printf "%03d" $LASTPL`
echo LASTPLFILLED=$LASTPLFILLED
echo  "$ORIGPLFILLED" == "$LASTPLFILLED" 
if [ "$ORIGPLFILLED" == "$LASTPLFILLED" ]; then
    echo "No new patchlevel available"
    CHANGES=0
fi
rm -rf dist/* 2>/dev/null
make unixall
# include patchlevel in tarball name so that older sources won't get overwritten:
mv dist/vim-${UPSTREAMMAJOR}.tar.bz2 dist/vim-${UPSTREAMMAJOR}-${LASTPLFILLED}.tar.bz2
# We don't include the full upstream changelog in the rpm changelog, just ship a file with
# the changes:
git log > dist/README.patches
popd

cp -f vim-upstream/dist/README.patches README.patches
cp -f vim-upstream/dist/vim-${UPSTREAMMAJOR}-${LASTPLFILLED}.tar.bz2 .
wget https://raw.githubusercontent.com/ignatenkobrain/vim-spec-plugin/master/ftplugin/spec.vim -O ftplugin-spec.vim
wget https://raw.githubusercontent.com/ignatenkobrain/vim-spec-plugin/master/syntax/spec.vim -O syntax-spec.vim
if [ $CHANGES -ne 0 ]; then
   CHLOG="* $DATE Karsten Hopp <karsten@redhat.com> $UPSTREAMMAJOR"
   $debug sed -i -e "/Release: /Release: %mkrel 1" $SPEC
   if [ "x$MAJORVERSION" != "x$UPSTREAMMAJOR" ]; then
      $debug sed -i -s "s/define baseversion: $MAJORVERSION/define baseversion: $UPSTREAMMAJOR=/" $SPEC
   fi
   $debug sed -i -e "s/define patchlevel $ORIGPLFILLED/define patchlevel $LASTPLFILLED/" $SPEC
   $debug sed -i -e "/\%changelog/a$CHLOG.$LASTPLFILLED-1\n- patchlevel $LASTPLFILLED\n" $SPEC
   $debug mgarepo sync vim-${UPSTREAMMAJOR}-${LASTPLFILLED}.tar.bz2
#   $debug svn add README.patches
#   $debug svn commit -m "- patchlevel $LASTPL" 
   if [ $? -eq 0 ]; then
#      $debug mgarepo submit
	echo "WOULD PUSH"
   else
      echo "GIT push failed"
   fi
fi
